@@ -18,7 +18,7 @@ function(xdata, ydata, tm = NULL, dm = "dea", rts = "crs", orientation = "n", g
   g.exe <- paste0("array(c(", 
                   paste0("xdata[,,", 1:dim(xdata)[3], "],", "ydata[,,", 1:dim(ydata)[3], "]", collapse=","), 
                   "), c(dim(xdata)[1], dim(xdata)[2] + dim(ydata)[2], dim(xdata)[3]))")
-  g     <- if(is.null(g)) eval(parse(text = g.exe)) else as.array(g)
+  gv    <- if(is.null(g)) eval(parse(text = g.exe)) else as.array(g)
   n     <- dim(xdata)[1]
   m     <- dim(xdata)[2]
   s     <- dim(ydata)[2]
@@ -28,24 +28,28 @@ function(xdata, ydata, tm = NULL, dm = "dea", rts = "crs", orientation = "n", g
   tm    <- if(is.null(tm)) paste0("t", 1:t) else as.vector(tm)
   
   # Model Arguments
+  m.arg <- list()
   if(dm %in% c("dea", "sbm")){
-    m.arg <- list(rts = rts, orientation = orientation)
+    for(i in 1:t){m.arg[[i]] <- list(rts = rts, orientation = orientation)}
   }else if(dm == "hdf"){
-    m.arg <- list(rts = rts, wd = wd)
+    for(i in 1:t){m.arg[[i]] <- list(rts = rts, wd = wd)}
   }else{
-    m.arg <- list(rts = rts, g = g, wd = wd)
+    for(i in 1:t){m.arg[[i]] <- list(rts = rts, g = gv[,,i], wd = wd)}
   }
   
   # Inter-temporal dm
   inter <- function(f, t){
     temp.it <- vector()
     for(j in 1:n){
-      temp.x  <- rbind(xdata[j,, f], as.matrix(xdata[,, t]))
-      temp.y  <- rbind(ydata[j,, f], as.matrix(ydata[,, t]))
-      temp.g  <- if(is.null(g)) cbind(temp.x, temp.y) else 
-        temp.se <- do.call(paste0("dm.", dm), append(list(xdata = temp.x, ydata = temp.y, se = T, o = 1), m.arg))
-      temp.no <- do.call(paste0("dm.", dm), append(list(xdata = temp.x, ydata = temp.y, se = F, o = 1), m.arg))
-      temp.it <- c(temp.it, ifelse(round(temp.no$eff[1], 5) < 1, temp.no$eff[1], temp.se$eff[1]))
+      temp.x  <- rbind(xdata[j,,f], as.matrix(xdata[,,t]))
+      temp.y  <- rbind(ydata[j,,f], as.matrix(ydata[,,t]))
+      temp.g  <- if(is.null(g)) cbind(temp.x, temp.y) else rbind(gv[j,,f], gv[,,t])
+      if(dm %in% c("dea", "sbm")){m.arg <- list(rts = rts, orientation = orientation)}
+      else if       (dm == "hdf"){m.arg <- list(rts = rts, wd = wd)}
+      else                       {m.arg <- list(rts = rts, g = temp.g, wd = wd)}
+      temp.se <- do.call(paste0("dm.", dm), append(list(xdata = temp.x, ydata = temp.y, se = T, o = 1), m.arg))$eff[1]
+      temp.no <- do.call(paste0("dm.", dm), append(list(xdata = temp.x, ydata = temp.y, se = F, o = 1), m.arg))$eff[1]
+      temp.it <- c(temp.it, ifelse(round(temp.no, 5) < 1, temp.no, temp.se))
     }
     return(temp.it)
   }
@@ -54,10 +58,10 @@ function(xdata, ydata, tm = NULL, dm = "dea", rts = "crs", orientation = "n", g
   cu <- fs <- mi <- data.frame()
   for(i in 1:(t-1)){
     # Within efficiency
-    m.0.0 <- do.call(paste0("dm.", dm), append(list(xdata = xdata[,, i],     ydata = ydata[,, i]),     m.arg))$eff
-    m.1.1 <- do.call(paste0("dm.", dm), append(list(xdata = xdata[,, i + 1], ydata = ydata[,, i + 1]), m.arg))$eff
+    m.0.0 <- do.call(paste0("dm.", dm), append(list(xdata = xdata[,,i],     ydata = ydata[,,i]),     m.arg[[i]]))$eff
+    m.1.1 <- do.call(paste0("dm.", dm), append(list(xdata = xdata[,,i + 1], ydata = ydata[,,i + 1]), m.arg[[i]]))$eff
     
-    # Inter-temporal efficiency
+    # Intertemporal efficiency
     m.0.1 <- inter(i,     i + 1)
     m.1.0 <- inter(i + 1, i    )
     
